summaryrefslogtreecommitdiff
path: root/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c')
-rw-r--r--src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c b/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c
index 634103a752..6c72d211ca 100644
--- a/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c
+++ b/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c
@@ -8,7 +8,7 @@
** Source: GetCalendarInfoW.c
**
** Purpose: Positive test the GetCalendarInfoW API.
** Call GetCalendarInfoW to retrive the information of a
** calendar
**
**
@@ -33,7 +33,7 @@ int __cdecl main(int argc, char *argv[])
err = GetCalendarInfoW(Locale,/*locale idendifier*/
CAL_GREGORIAN, /*calendar identifier*/
CalType, /*calendar tyope*/
- NULL, /*buffer to store the retrive info*/
+ NULL, /*buffer to store the retrieve info*/
0, /*alwayse zero*/
&dwValue);/*to store the requrest data*/
if (0 == err)
@@ -44,7 +44,7 @@ int __cdecl main(int argc, char *argv[])
err = GetCalendarInfoW(Locale,/*locale idendifier*/
CAL_GREGORIAN_US, /*calendar identifier*/
CalType, /*calendar tyope*/
- NULL, /*buffer to store the retrive info*/
+ NULL, /*buffer to store the retreive info*/
0, /*alwayse zero*/
&dwValue);/*to store the requrest data*/
if (0 == err)
@@ -8,7 +8,7 @@
**
** Purpose: Positive test the GetCalendarInfoW API.
-** Call GetCalendarInfoW to retrive the information of a
+** Call GetCalendarInfoW to retrieve the information of a
** calendar
**